/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.webroot.jsxpframework.examples.forminputvalidation;

import org.jsxp.framework.Context;
import org.jsxp.framework.Validator;
import org.jsxp.framework.elementprocessing.processors.MarkInvalid;
import org.jsxp.framework.util.text.StringUtil;
import org.jsxp.framework.webroot.generated.jsxpframework.examples.forminputvalidation.IndexXhtmlControllerGenerated;
import org.jsxp.framework.webroot.generated.jsxpframework.examples.forminputvalidation.Step2XhtmlControllerGenerated;

public class Step2XhtmlController extends Step2XhtmlControllerGenerated {

	private final Input input = new Input();

	@Override
	public void execute() {
		getElementText().setValue(input.getName());
	}

	@Override
	public Object getInputParameterBean() {
		return input;
	}

	@Override
	public void validate() throws Exception {
		final Validator validator = getValidator();
		validator.validate(
				!StringUtil.isEmpty(input.getName()) &&
				!StringUtil.isEmpty(input.getName().trim())
				, "please fill out all necessary field in the form",
				new MarkInvalid(IndexXhtmlControllerGenerated.getIdElementNameInput(), "please provide a name"));
		if (validator.hasErrors()) {
			Context.getContext().redirect(new IndexXhtmlController(), false, null);
		}
	}
}
