/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.adapter.impl.org.jsxp.framework.fileupload.adapter;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

/**
 * Class to encapsulate file upload in web application via Apache Commons FileUpload.
 * Uses reflection to find the Apache classes to compile without the classes in
 * the classpath.
 *
 */
public class FileUpload implements org.jsxp.framework.fileupload.adapter.FileUpload
{
	public LinkedList<String> allowedContent;
	public Object diskFileItemFactory;
	@SuppressWarnings("rawtypes")
	public Class diskFileItemFactoryClass;
	@SuppressWarnings("rawtypes")
	public Class fileItemClass;
	public Method fileItemClass_getFieldName;
	public Method fileItemClass_getString;
	public Method fileItemClass_isFormField;
	public boolean fileUploadSupported;
	@SuppressWarnings("rawtypes")
	public Class servletFileUploadClass;
	@SuppressWarnings("rawtypes")
	public Constructor servletFileUploadClass_constructor;
	public Method servletFileUploadClass_isMultipartContent;
	public Method servletFileUploadClass_parseRequest;

	/**
	 * Constructor
	 */
	public FileUpload()
	{
		initApacheCommonsFileUpload();
	}

	private Object createServletFileUploadObject()
	{
		try
		{
			return servletFileUploadClass_constructor.newInstance(diskFileItemFactory);
		}
		catch (final Exception e)
		{
			return null;
		}
	}

	private String fileItem_getFieldName(final Object item) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException
	{
		return (String) fileItemClass_getFieldName.invoke(item);
	}

	private String fileItem_getString(final Object item) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException
	{
		return (String) fileItemClass_getString.invoke(item);
	}

	private boolean fileItem_isFormField(final Object item) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException
	{
		return ((Boolean) fileItemClass_isFormField.invoke(item)).booleanValue();
	}

	@SuppressWarnings("unchecked")
	private void initApacheCommonsFileUpload()
	{
		try
		{
			diskFileItemFactoryClass = Class.forName("org.apache.commons.fileupload.disk.DiskFileItemFactory");
			diskFileItemFactory = diskFileItemFactoryClass.newInstance();
			servletFileUploadClass = Class.forName("org.apache.commons.fileupload.servlet.ServletFileUpload");
			servletFileUploadClass_isMultipartContent = servletFileUploadClass.getMethod("isMultipartContent", HttpServletRequest.class);
			servletFileUploadClass_parseRequest = servletFileUploadClass.getMethod("parseRequest", HttpServletRequest.class);
			servletFileUploadClass_constructor = servletFileUploadClass.getConstructor(diskFileItemFactoryClass);
			fileItemClass = Class.forName("org.apache.commons.fileupload.FileItem");
			fileItemClass_isFormField = fileItemClass.getMethod("isFormField");
			fileItemClass_getFieldName = fileItemClass.getMethod("getFieldName");
			fileItemClass_getString = fileItemClass.getMethod("getString");
			fileUploadSupported = true;
		}
		catch (final Exception e)
		{
			fileUploadSupported = false;
		}
	}

	/* (non-Javadoc)
	 * @see org.jsxp.framework.framework.adapter.WebApplicationFileUploadAdapter#isFileUploadSupported(javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public boolean isFileUploadSupported(final HttpServletRequest request)
	{
		return fileUploadSupported && isMultipartContent(request);
	}

	private boolean isMultipartContent(final HttpServletRequest request)
	{
		try
		{
			return (Boolean)servletFileUploadClass_isMultipartContent.invoke(servletFileUploadClass, request);
		}
		catch (final Exception e)
		{
			return false;
		}
	}

	/* (non-Javadoc)
	 * @see org.jsxp.framework.framework.adapter.WebApplicationFileUploadAdapter#parseUploadRequest(javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public Map<String, Object[]> parseUploadRequest(final HttpServletRequest request)
	{
		final Object servletFileUpload = createServletFileUploadObject();
		List<Object> items;
		try {
			items = servletFileUpload_parseRequest(servletFileUpload, request);


			final Map<String, Object[]> requestInputParameters = new HashMap<String, Object[]>();
			for (final Object item : items) {
				if (fileItem_isFormField(item)) {
					requestInputParameters.put(fileItem_getFieldName(item), new String[] {fileItem_getString(item)});
				} else {
					requestInputParameters.put(fileItem_getFieldName(item), new Object[] {item});
				}
			}

			return requestInputParameters;

		} catch (final Exception e) {
			return null;
		}
	}

	@SuppressWarnings("unchecked")
	private List<Object> servletFileUpload_parseRequest(final Object servletFileUpload, final HttpServletRequest request) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException
	{
		return (List<Object>) servletFileUploadClass_parseRequest.invoke(servletFileUpload, request);
	}
}