/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.webroot.jsxpframework.examples;

import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.net.URI;

import org.jsxp.framework.Application;
import org.jsxp.framework.Context;
import org.jsxp.framework.util.text.StringUtils;
import org.jsxp.framework.webroot.generated.jsxpframework.examples.SourceViewXhtmlControllerGenerated;

public class SourceViewXhtmlController extends SourceViewXhtmlControllerGenerated {

	Input input = new Input();

	@Override
	public void execute() throws Exception {
		final String name = input.getUri();

		if (name.indexOf("..") >= 0) {
			Context.getContext().redirect(Application.getApplication().getViewForbiddenViewController(), false, null);
		}

		String prefix = null;
		if (name.endsWith(".java")) {
			prefix = "/jsxpframework/examples/src/org/jsxp/framework/webroot/jsxpframework/examples";
		} else {
			prefix = "/jsxpframework/examples";
		}

		URI uri = new URI(StringUtils.combine("/", true, prefix, name));
		uri = uri.normalize();

		setVariableName(name);

		final InputStream is = Application.getApplication().getResourceInputStream(uri.toString(), this);
		final ByteArrayOutputStream baos = new ByteArrayOutputStream();

		if(is != null) {
			final byte[] buffer = new byte[1024];
			int numBytes = is.read(buffer);
			while(numBytes != -1) {
				baos.write(buffer, 0, numBytes);
				numBytes = is.read(buffer);
			}
		}

		getElementContent().setValue(baos.toString());

	}

	@Override
	public Object getInputParameterBean() {
		return input;
	}

}
