/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.webroot.jsxpframework.examples.ajax;

import org.jsxp.framework.Context;
import org.jsxp.framework.Element;
import org.jsxp.framework.elementprocessing.ElementProcessorCommand;
import org.jsxp.framework.elementprocessing.processors.AjaxBehaviour;
import org.jsxp.framework.webroot.generated.jsxpframework.examples.ajax.IndexXhtmlControllerGenerated;
import org.jsxp.framework.webroot.jsxpframework.components.ajax.AjaxXhtmlController;

public class IndexXhtmlController extends IndexXhtmlControllerGenerated {

	private static int counter = 0;

	@Override
	public void execute() throws Exception
	{
		importView(new AjaxXhtmlController());

		// configure the example page.
		// the execute method will be only called if the
		// view belonging to this view controller is directly called
		// with a normal or a partial request (Ajax).
		// it is not executed when a command is called via the client and
		// executed on the server.

		// the example shows different ways of using Ajax.

		// 1. example
		// adds a processor that will change the submitLink2 in html
		// to use an Ajax request when clicked
		// this will a partial request, so the full view controller lifecycle be used
		// but only some elements with jsxp ids will be updated on the client
		addElementProcessor(new AjaxBehaviour(getElementSubmitLink2(), getIdElementCounter()));

		// 2. example
		// create a command to use for submitLink3 in html
		final ElementProcessorCommand command = new ElementProcessorCommand() {

			private static final long serialVersionUID = -4068630674888541459L;

			@Override
			public Element process() {
				counter--;
				getElementCounter().setValue(counter+ " (command executed)");
				renewCommand();
				return getRootElement();
			}

		};

		// still 2. example
		// adds a command to submitLink3 that is executed on the server
		// when the link is clicked.
		// instead of rendering a view with a complete view controller lifecycle
		// this will only call the command on the server. the command
		// returns an element, that is rendered and send to the client.
		// commands are the easiest way to implement ajax that calls server side code
		addElementProcessor(new AjaxBehaviour(getElementSubmitLink3(), command, getIdElementCounter()));

		// the following code will be used if
		// the view is just called with a normal or a partial request
		// (so everytime the page is directly called via browser,
		// or if the link from example 2 is used).
		if (Context.getContext().isPartialRequest()) {
			counter++;
			getElementCounter().setValue(counter+" (partial request)");
		} else {
			counter = 0;
			getElementCounter().setValue(0+" (normal request)");
		}
	}
}
