/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework;

import org.jsxp.framework.ViewControllerLifeCycle.LifeCyclePhase;

/**
 * The listener interface for receiving phase events.
 * The class that is interested in processing a phase
 * event implements this interface, and the object created
 * with that class is registered with a component using the
 * component's <code>addPhaseListener<code> method. When
 * the phase event occurs, that object's appropriate
 * method is invoked.
 * 
 */
public interface PhaseListener {

	/**
	 * After phase.
	 * 
	 * @param phase the phase
	 */
	public void afterPhase(LifeCyclePhase phase);

	/**
	 * Before phase.
	 * 
	 * @param phase the phase
	 */
	public void beforePhase(LifeCyclePhase phase);

}
