/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework;


/**
 * The default ProjectStage class. You can create subclasses if you need a special behaviour in
 * different project stages. Or you can check the project stage in your code to react in
 * different ways.
 */
public class ProjectStage {
	private final String name;
	private boolean useDebugMessagesViewController = false;
	private boolean useDeveloperWarningsViewController = false;
	private boolean useScopeMessagesViewController = false;

	/**
	 * Instantiates a new project stage. You should use {@link Application#createProjectStage(String)}
	 * to create a new instance of project stage, so that is is directly configurated.
	 * 
	 * @param name the name
	 */
	public ProjectStage(final String name) {
		this.name = name;
	}

	/**
	 * Gets the name.
	 * 
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * Sets the use debug messages view control.
	 * 
	 * @param debug the new use debug messages view control
	 */
	void setUseDebugMessagesViewController(final boolean debug) {
		this.useDebugMessagesViewController = debug;
	}

	/**
	 * Sets the use developer warnings view control.
	 * 
	 * @param debug the new use developer warnings view control
	 */
	void setUseDeveloperWarningsViewController(final boolean debug) {
		this.useDeveloperWarningsViewController = debug;
	}

	/**
	 * Sets the use scope messages view control.
	 * 
	 * @param debug the new use scope messages view control
	 */
	void setUseScopeMessagesViewController(final boolean debug) {
		this.useScopeMessagesViewController = debug;
	}

	/**
	 * Use debug messages view control.
	 * 
	 * @return true, if successful
	 */
	public boolean useDebugMessagesViewController() {
		return useDebugMessagesViewController;
	}

	/**
	 * Use developer warnings view control.
	 * 
	 * @return true, if successful
	 */
	public boolean useDeveloperWarningsViewController() {
		return useDeveloperWarningsViewController;
	}

	/**
	 * Use scope messages view control.
	 * 
	 * @return true, if successful
	 */
	public boolean useScopeMessagesViewController() {
		return useScopeMessagesViewController;
	}

}
