/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework;

import java.util.Map;

/**
 * The Class Scopes. Basic container for the different scopes.
 */
public class Scopes<K, V> {

	private Map<K, V> applicationAttributes = null;

	private Map<K, V> applicationScope = null;
	private FlashMap<K, V> flashAttributes = null;
	private FlashMap<K, V> flashScope = null;
	private Map<K, V> requestAttributes = null;
	private Map<K, V> requestScope = null;
	private Map<K, V> sessionAttributes = null;
	private Map<K, V> sessionScope = null;
	private Map<K, V> viewAttributes = null;
	private Map<K, V> viewScope = null;
	/**
	 * Instantiates a new scopes.
	 */
	Scopes() {
	}

	/**
	 * Gets the application attributes.
	 * 
	 * @return the application attributes
	 */
	public Map<K, V> getApplicationAttributes() {
		return applicationAttributes;
	}

	/**
	 * Gets the application scope.
	 * 
	 * @return the application scope
	 */
	public Map<K, V> getApplicationScope() {
		return applicationScope;
	}

	/**
	 * Gets the flash attributes.
	 * 
	 * @return the flash attributes
	 */
	public Map<K, V> getFlashAttributes() {
		return flashAttributes;
	}

	/**
	 * Gets the flash scope.
	 * 
	 * @return the flash scope
	 */
	public Map<K, V> getFlashScope() {
		return flashScope;
	}

	/**
	 * Gets the request attributes.
	 * 
	 * @return the request attributes
	 */
	public Map<K, V> getRequestAttributes() {
		return requestAttributes;
	}

	/**
	 * Gets the request scope.
	 * 
	 * @return the request scope
	 */
	public Map<K, V> getRequestScope() {
		return requestScope;
	}

	/**
	 * Gets the session attributes.
	 * 
	 * @return the session attributes
	 */
	public Map<K, V> getSessionAttributes() {
		return sessionAttributes;
	}

	/**
	 * Gets the session scope.
	 * 
	 * @return the session scope
	 */
	public Map<K, V> getSessionScope() {
		return sessionScope;
	}

	/**
	 * Gets the view attributes.
	 * 
	 * @return the view attributes
	 */
	public Map<K, V> getViewAttributes() {
		return viewAttributes;
	}

	/**
	 * Gets the view scope.
	 * 
	 * @return the view scope
	 */
	public Map<K, V> getViewScope() {
		return viewScope;
	}

	/**
	 * Renew flash attributes.
	 */
	public void renewFlashAttributes() {
		flashAttributes.renew();
	}

	/**
	 * Renew flash attributes.
	 * 
	 * @param key the key
	 */
	void renewFlashAttributes(final K key) {
		flashAttributes.renew(key);
	}

	/**
	 * Renew flash scope.
	 * 
	 * @param key the key
	 */
	public void renewFlashScope(final K key) {
		flashScope.renew(key);
	}

	/**
	 * Sets the application attributes.
	 * 
	 * @param applicationAttributes the application attributes
	 */
	void setApplicationAttributes(final Map<K, V> applicationAttributes) {
		this.applicationAttributes = applicationAttributes;
	}

	/**
	 * Sets the application scope.
	 * 
	 * @param applicationScope the application scope
	 */
	void setApplicationScope(final Map<K, V> applicationScope) {
		this.applicationScope = applicationScope;
	}

	/**
	 * Sets the flash attributes.
	 * 
	 * @param flashAttributes the flash attributes
	 */
	void setFlashAttributes(final FlashMap<K, V> flashAttributes) {
		this.flashAttributes = flashAttributes;
	}

	/**
	 * Sets the flash scope.
	 * 
	 * @param flashScope the flash scope
	 */
	void setFlashScope(final FlashMap<K, V> flashScope) {
		this.flashScope = flashScope;
	}

	/**
	 * Sets the request attributes.
	 * 
	 * @param requestAttributes the request attributes
	 */
	void setRequestAttributes(final Map<K, V> requestAttributes) {
		this.requestAttributes = requestAttributes;
	}

	/**
	 * Sets the request scope.
	 * 
	 * @param requestScope the request scope
	 */
	void setRequestScope(final Map<K, V> requestScope) {
		this.requestScope = requestScope;
	}

	/**
	 * Sets the session attributes.
	 * 
	 * @param sessionAttributes the session attributes
	 */
	void setSessionAttributes(final Map<K, V> sessionAttributes) {
		this.sessionAttributes = sessionAttributes;
	}

	/**
	 * Sets the session scope.
	 * 
	 * @param sessionScope the session scope
	 */
	void setSessionScope(final Map<K, V> sessionScope) {
		this.sessionScope = sessionScope;
	}

	/**
	 * Sets the view attributes.
	 * 
	 * @param viewAttributes the view attributes
	 */
	void setViewAttributes(final Map<K, V> viewAttributes) {
		this.viewAttributes = viewAttributes;
	}

	/**
	 * Sets the view scope.
	 * 
	 * @param viewScope the view scope
	 */
	void setViewScope(final Map<K, V> viewScope) {
		this.viewScope = viewScope;
	}

}
