/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework;

import java.io.Serializable;

import org.jsxp.framework.elementprocessing.ElementProcessor;
import org.jsxp.framework.elementprocessing.processors.MarkInvalid;


/**
 * The Class ValidationError. Encapsulates a validation error. You need it, if you use
 * the jsxp frameworks basic validation features to validate input parameter.
 * 
 * @see Validator
 */
public class ValidationError implements Serializable {
	private static final long serialVersionUID = 1L;

	private ElementProcessor[] elementProcessors;
	private String message;

	/**
	 * Instantiates a new validation error.
	 * 
	 * @param message the message
	 * @param elementProcessors element processors you want to use (like {@link MarkInvalid})
	 */
	public ValidationError(final String message, final ElementProcessor... elementProcessors) {
		this.message = message;
		this.elementProcessors = elementProcessors;
	}

	/**
	 * Gets the element processors to process for that error
	 * 
	 * @return elementProcessors
	 */
	public ElementProcessor[] getElementProcessors() {
		return elementProcessors;
	}

	/**
	 * Gets the message.
	 * 
	 * @return the message
	 */
	public String getMessage() {
		return message;
	}

	/**
	 * Sets the element processors to process for that error
	 * 
	 * @param elementProcessors
	 */
	public void setElementProcessors(
			final ElementProcessor... elementProcessors) {
		this.elementProcessors = elementProcessors;
	}

	/**
	 * Sets the message.
	 * 
	 * @param message the new message
	 */
	public void setMessage(final String message) {
		this.message = message;
	}
}
