/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework;

import java.io.Serializable;
import java.util.Map;

/**
 * The Class ViewAlias. Encapsulates an alias to a view. You can use it if you want to
 * redirect to another view or want to save a requested view and the request parameter.
 */
public class ViewAlias implements Serializable {
	private static final long serialVersionUID = 1L;
	private final Map<String, Object[]> getParameters;
	private transient ViewController viewController;
	private final String viewFileName;

	/**
	 * Instantiates a new view alias.
	 * 
	 * @param viewFileName the view file name
	 * @param getParameters the get parameters
	 */
	public ViewAlias(final String viewFileName, final Map<String, Object[]> getParameters) {
		this.getParameters = getParameters;
		this.viewFileName = viewFileName;
	}

	/**
	 * Instantiates a new view alias.
	 * 
	 * @param viewController the view control
	 * @param getParameters the get parameters
	 */
	public ViewAlias(final ViewController viewController, final Map<String, Object[]> getParameters) {
		this.viewController = viewController;
		this.getParameters = getParameters;
		this.viewFileName = viewController.getViewFilename();
	}

	/**
	 * Gets the gets the parameters.
	 * 
	 * @return the gets the parameters
	 */
	public Map<String, Object[]> getGetParameters() {
		return getParameters;
	}

	/**
	 * Gets the view control.
	 * 
	 * @return the view control
	 */
	public ViewController getViewController() {
		if (viewController != null) {
			return viewController;
		} else {
			return Application.getApplication().getViewController(viewFileName);
		}

	}

	/**
	 * Gets the view filename
	 * 
	 * @return the view filename
	 */
	public String getViewFilename() {
		return viewFileName;
	}

}
