/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework;


public interface ViewControllerLifeCycleExceptionHandler {

	/**
	 * Handle executing exception. If the {@link ViewController#execute()} method / the executing phase of
	 * a view controller ends with an exception that is not catched in any other handler this
	 * method is called. Only if the exception is not catch here, the exception will be thrown further.
	 * 
	 * @param e the e
	 * @param source the source
	 */
	public void handleExecutingException(Exception e, ViewController source);

	/**
	 * If the an exception is thrown in initializing phase in the {@link ViewController#init()} method this
	 * method is called. Only if the exception is not catch here, the exception will be thrown further.
	 * 
	 * @param e the e
	 * @param source the source
	 */
	public void handleInitException(Exception e, ViewController source);

	/**
	 * Handle input processing exception. If the an exception is thrown in input processing phase
	 * that is not catched in any other handler this
	 * method is called. Only if the exception is not catch here, the exception will be thrown further.
	 * 
	 * 
	 * @param e the e
	 * @param source the source
	 */
	public void handleInputProcessingException(Exception e, ViewController source);

	/**
	 * Handle preparing exception. If the an exception is thrown in preparing phase
	 * that is not catched in any other handler this
	 * method is called. Only if the exception is not catch here,
	 * the exception will be thrown further.
	 * 
	 * 
	 * @param e the e
	 * @param source the source
	 */
	public void handlePreparingException(Exception e, ViewController source);

	/**
	 * Handle rendering exception. If the an exception is thrown in rendering phase of a view controller
	 * that is not catched in any other handler this
	 * method is called. Only if the exception is not catch here, the exception will be thrown further.
	 * 
	 * @param e the e
	 * @param source the source
	 */
	public void handleRenderingException(Exception e, ViewController source);

	/**
	 * Handle templating exception. If the an exception is thrown in templating phase
	 * that is not catched in any other handler this
	 * method is called. Only if the exception is not catch here, the exception will be thrown further.
	 * 
	 * @param e the e
	 * @param source the source
	 */
	public void handleTemplatingException(Exception e, ViewController source);

	/**
	 * Handle validating exception. If the an exception is thrown in validating phase in the
	 * {@link ViewController#validate()} method that is not catched in any other handler this
	 * method is called. Only if the exception is not catch here,
	 * the exception will be thrown further.
	 * 
	 * 
	 * @param e the e
	 * @param source the source
	 */
	public void handleValidatingException(Exception e, ViewController source);
}
