/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework;

import java.io.OutputStream;
import java.util.Map;

import org.jsxp.framework.internal.InternalElement;
import org.jsxp.framework.resources.ResourceResolver;


/**
 * The Interface ViewParser that defines a parser for a view.
 */
public interface ViewParser {

	/**
	 * Gets the id attribute name.
	 * 
	 * @return the id attribute name
	 */
	public String getIdAttributeName();

	/**
	 * Gets the id namespace.
	 * 
	 * @return the id namespace
	 */
	public String getIdNamespace();

	/**
	 * Parses the element.
	 * 
	 * @param uri the uri
	 * @param resolver the resolver
	 * @param contextObjectForResolver the context object for resolver
	 * @param idPrefix the id prefix
	 * @param idElements the id elements
	 * @param rootElement the root element
	 * @param sourceViewController the source view controller
	 * 
	 * @return the internal element
	 */
	public InternalElement read(String uri, ResourceResolver resolver, Object contextObjectForResolver, String idPrefix,
			Map<String, InternalElement> idElements, InternalElement rootElement, ViewController sourceViewController);

	/**
	 * Sets the id attribute name.
	 * 
	 * @param idAttributeName the new id attribute name
	 */
	public void setIdAttributeName(String idAttributeName);

	/**
	 * Sets the id namespace.
	 * 
	 * @param idNamespace the new id namespace
	 */
	public void setIdNamespace(String idNamespace);

	/**
	 * Render the element hierarchy to the output stream
	 * 
	 * @param elem the elem
	 * @param os the os
	 * @param contentType the content type
	 */
	public void write(InternalElement elem, OutputStream os, String contentType);
}
