/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.dom.adapter;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.TransformerFactoryConfigurationError;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.xml.sax.SAXException;


public class XMLTransformer
{
	private static DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
	static {
		dbf.setNamespaceAware(true);
		dbf.setSchema(null);
		dbf.setValidating(false);
		//dbf.setExpandEntityReferences(false);  // false => sub nodes for entities
		try
		{
			dbf.setFeature("http://apache.org/xml/features/nonvalidating/load-external-dtd", false);
			dbf.setFeature("http://apache.org/xml/features/scanner/notify-char-refs", false);
			dbf.setFeature("http://apache.org/xml/features/scanner/notify-builtin-refs", false);
			// create node for entities or directly expose it
			dbf.setFeature("http://apache.org/xml/features/dom/create-entity-ref-nodes", true);
		}
		catch (final ParserConfigurationException e)
		{
		}
	}

	private final TransformerFactory factory = TransformerFactory.newInstance();

	public Document read(final InputStream inputStream) throws ParserConfigurationException, SAXException, IOException {
		final DocumentBuilder parser =
				dbf.newDocumentBuilder();
		final Document document = parser.parse(inputStream);
		return document;
	}

	public void write(final Node node, final OutputStream os, final String contentType) {

		Transformer transformer = null;
		try {
			transformer = factory.newTransformer();
			if (contentType != null && contentType.equals("text/html")) {
				transformer.setOutputProperty(OutputKeys.METHOD, "html");
			}
			//transformer.setOutputProperty(OutputKeys.OMIT_XML_DECLARATION,"yes");
			//transformer.setOutputProperty(OutputKeys.ENCODING, node.getOwnerDocument().getInputEncoding());
		} catch (final TransformerConfigurationException e) {
			throw new RuntimeException(e);
		} catch (final TransformerFactoryConfigurationError e) {
			throw new RuntimeException(e);
		}
		final DOMSource source = new DOMSource( node );
		final StreamResult result = new StreamResult( os );

		try {
			transformer.transform( source, result );
			transformer.transform( source, new StreamResult( System.out ) );
		} catch (final TransformerException e) {
			throw new RuntimeException(e);
		}
	}
}