/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.elementprocessing;

import java.io.Serializable;
import java.util.HashMap;

import org.jsxp.framework.Context;
import org.jsxp.framework.Element;


/**
 * Defines how view resources (for examples used for scripts that are needed by views and have to be
 * included as a link to HTML head) are handled by the jsxp framework. There are different processor
 * implementations for different task. You can implement your own processors and use them.
 */
public abstract class ElementProcessorCommand implements Serializable {

	/**
	 * 
	 */
	protected static final long serialVersionUID = -9064706374177096374L;

	public ElementProcessorCommand() {
	}

	/**
	 * Process method
	 */
	public abstract Element process();

	/**
	 * put the command again in the user session, so it is available for another call
	 */
	@SuppressWarnings("unchecked")
	public void renewCommand() {
		final HashMap<String, ElementProcessorCommand> elementProcessorCommands =
				(HashMap<String, ElementProcessorCommand>)
				Context.getContext().getScopes().getSessionAttributes().get(ElementProcessorCommand.class.getName());

		if (elementProcessorCommands != null) {
			elementProcessorCommands.put(this.toString(), this);
		}
	}
}
