/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.elementprocessing.processors;

import org.jsxp.framework.Element;
import org.jsxp.framework.ViewController;
import org.jsxp.framework.elementprocessing.ElementProcessor;
import org.jsxp.framework.util.text.StringUtil;


/**
 * This processor will mark an element as invalid by enabling a red border around it and setting a message
 * as a title.
 */
public class MarkInvalid implements ElementProcessor {

	private Element element = null;
	private String elementId = null;
	private String elementIdPrefix = null;
	private int index = 0;
	private String message = null;

	/**
	 * Instantiates a new resource handler.
	 * @param element the element to process
	 * @param message optional error message
	 */
	public MarkInvalid(final Element element, final String message) {
		this.element = element;
		this.message = message;
	}

	/**
	 * Instantiates a new resource handler.
	 * @param elementId
	 * @param index
	 * @param message
	 */
	public MarkInvalid(final String elementId, final int index, final String message) {
		this(null, elementId, index, message);
	}

	/**
	 * Instantiates a new resource handler.
	 * @param elementId
	 * @param message
	 */
	public MarkInvalid(final String elementId, final String message) {
		this(null, elementId, -1, message);
	}

	/**
	 * Instantiates a new resource handler.
	 * @param elementIdPrefix
	 * @param elementId
	 * @param index
	 * @param message
	 */
	public MarkInvalid(final String elementIdPrefix, final String elementId, final int index, final String message) {
		this.elementId = elementId;
		this.elementIdPrefix= elementIdPrefix;
		this.index = index;
		this.message = message;
	}

	/**
	 * Instantiates a new resource handler.
	 * @param elementIdPrefix
	 * @param elementId
	 * @param message
	 */
	public MarkInvalid(final String elementIdPrefix, final String elementId, final String message) {
		this(elementIdPrefix, elementId, -1, message);
	}

	/*
	 * (non-Javadoc)
	 * @see org.jsxp.framework.elementprocessing.ElementProcessor#process(org.jsxp.framework.ViewController)
	 */
	@Override
	public void process(final ViewController renderViewController) {
		if (element == null) {
			element = renderViewController.getElement(elementIdPrefix, elementId, index);
		}

		final String previousMessage = element.getAttribute("title");
		if(StringUtil.isEmpty(previousMessage)) {
			element.setAttribute("title", message);
		} else {
			element.setAttribute("title", previousMessage+", "+message);
		}
		element.setAttribute("style", "border: 1px solid red;");
	}
}
