/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.elementprocessing.processors;

import org.jsxp.framework.Context;
import org.jsxp.framework.Element;
import org.jsxp.framework.ViewController;
import org.jsxp.framework.elementprocessing.ElementProcessor;
import org.jsxp.framework.util.text.StringUtils;


/**
 * Implementation for {@link ResourceBundleValue} for web environments. This
 * implementation renders a resource that a view controller uses as a link in the HTML-head. This
 * resource handler can be used for stylesheets or javascript (text/css, text/javascript resource type) files.
 */
public class RelativeUri implements ElementProcessor {

	private Element element = null;
	private String key = null;

	/**
	 * Instantiates a new resource handler.
	 * @param element the element to process
	 * @param key used to check what keys are already processed so we can prevent to add stuff in head twices (most time you can use the link uri)
	 */
	public RelativeUri(final Element element, final String key) {
		this.element = element;
		this.key = key;
	}


	/*
	 * (non-Javadoc)
	 * @see org.jsxp.framework.elementprocessing.ElementProcessor#process(org.jsxp.framework.ViewController)
	 */
	@Override
	public void process(final ViewController renderViewController) {
		final String uri = element.getAttribute(key);
		final ViewController sourceViewController = element.getSourceViewController();
		final String sourceViewControllerPath = sourceViewController.getViewFilename();
		String rootPath = sourceViewControllerPath;
		int slashIndex = rootPath.lastIndexOf("/");
		if (slashIndex > -1) {
			rootPath = rootPath.substring(0, slashIndex);
		}

		String rootPathRender = renderViewController.getViewFilename();
		slashIndex = rootPathRender.lastIndexOf("/");
		if (slashIndex > -1) {
			rootPathRender = rootPathRender.substring(0, slashIndex);
		}

		element.setAttribute(key, StringUtils.combine("/", true, Context.getContext().getContextPath(), rootPath, uri));
	}
}
