/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.fileupload.adapter;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

/**
 * Adapter interface for file upload implementations to use for the request
 * input parameter.
 * 
 */
public interface FileUpload
{

	/**
	 * Checks wether file upload is supported for that request or not.
	 * @param request
	 * @return if file upload is supported by this implementation
	 */
	public abstract boolean isFileUploadSupported(HttpServletRequest request);

	/**
	 * Parses an upload request and returns an map with the different uploads
	 * (for multiple uploads) ordered by key (form property name) and
	 * corresponding object (type depends on implementation).
	 * @param request
	 * @return he input parameter from the parsed upload request
	 */
	public abstract Map<String, Object[]> parseUploadRequest(
			HttpServletRequest request);

}