/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.internal;

import org.jsxp.framework.Element;

/**
 * Used only internally by the jsxp framework to mark and process
 * elements and their variables. Needed to support different element implementations
 * (e.g. the default DOM-implementation). An internal element is the runtime representation
 * of any view element. In extension to the interface {@link Element} this interface defines
 * method for internal framework use only.
 */
public interface InternalElement extends Element {

	/**
	 * Gets the variable value.
	 * 
	 * @param key the key
	 * 
	 * @return the variable value
	 */
	String getVariableValue(String key);

	/**
	 * Substitute variables. A method call will trigger the variable substitution for
	 * the implementing element.
	 */
	void substituteVariables();

}
