/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.resources;

import java.io.InputStream;

/**
 * The Interface ResourceResolver. Needed to get a resource from an input stream and
 * to calculate a ModifierTimeStamp for it. For simple files to modifierTimeStamp can be
 * the last modified date. This interface is needed to support resources from any source
 * (network, database, filesystem, ...)
 * 
 * @see ViewResourceResolver
 */
public interface ResourceResolver {

	/**
	 * Gets the resource input stream.
	 * 
	 * @param uri the uri
	 * @param objectForClassLoader the object for class loader
	 * 
	 * @return the resource input stream
	 */
	public InputStream getResourceInputStream(String uri, Object objectForClassLoader);

	/**
	 * Gets the resource modified time stamp.
	 * 
	 * @param uri the uri
	 * @param objectForClassLoader the object for class loader
	 * 
	 * @return the resource modified time stamp
	 */
	public long getResourceModifiedTimeStamp(String uri, Object objectForClassLoader);
}
