/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.resources;

import java.io.InputStream;

/**
 * A view resource resolver that just gets a view resource from an input stream.
 * Can be overriden in a web app to support special input possibilities where to get
 * a view from.
 */
public class ViewResourceResolver implements ResourceResolver {

	private final InputStream inputStream;
	private final long lastModified;

	/**
	 * Instantiates a new view resolver that just gets a view resource from an input stream.
	 * Can be overriden in a web app to support special input possibilities where to get
	 * a view from.
	 * 
	 * @param lastModified the last modified
	 * @param inputStream the input stream
	 */
	public ViewResourceResolver(final long lastModified, final InputStream inputStream) {
		this.lastModified = lastModified;
		this.inputStream = inputStream;
	}

	/* (non-Javadoc)
	 * @see org.jsxp.framework.ResourceResolver#getResourceInputStream(java.lang.String, java.lang.Object)
	 */
	@Override
	public InputStream getResourceInputStream(final String uri, final Object objectForClassLoader) {
		return inputStream;
	}

	/* (non-Javadoc)
	 * @see org.jsxp.framework.ResourceResolver#getResourceModifiedTimeStamp(java.lang.String, java.lang.Object)
	 */
	@Override
	public long getResourceModifiedTimeStamp(final String uri, final Object objectForClassLoader) {
		return lastModified;
	}
}
