/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.webroot.jsxpframework.components;

import org.jsxp.framework.Context;
import org.jsxp.framework.Element;
import org.jsxp.framework.ElementTemplate;
import org.jsxp.framework.PhaseListener;
import org.jsxp.framework.ViewController;
import org.jsxp.framework.ViewControllerLifeCycle.LifeCyclePhase;
import org.jsxp.framework.webroot.generated.jsxpframework.components.DebugMessagesXhtmlControllerGenerated;


/**
 * The Class DebugMessagesXhtmlController. {@link ViewController} for the basic jsxp debug messages
 * component. This view controller is used per default to show the debug messages you can
 * add to the context on the result page from the requested view.
 * 
 * @see Context#addDebugMessage(String)
 */
public class DebugMessagesXhtmlController extends DebugMessagesXhtmlControllerGenerated {

	private class DebugMessagesPhaseListener implements PhaseListener {

		/* (non-Javadoc)
		 * @see org.jsxp.framework.framework.PhaseListener#afterPhase(org.jsxp.framework.framework.ViewControllerLifeCycle.LifeCyclePhase)
		 */
		@Override
		public void afterPhase(final LifeCyclePhase phase) {
		}

		/* (non-Javadoc)
		 * @see org.jsxp.framework.framework.PhaseListener#beforePhase(org.jsxp.framework.framework.ViewControllerLifeCycle.LifeCyclePhase)
		 */
		@Override
		public void beforePhase(final LifeCyclePhase phase) {
			if (!Context.getContext().getUpdateIds().isEmpty()) {
				Context.getContext().getUpdateIds().add(getElementDebugComponent().getId());
			}

			ViewController ViewController = getParent();
			while (ViewController.getViewTemplate() != null) {
				ViewController = ViewController.getViewTemplate();
			}
			if(!Context.getContext().getDebugMessages().isEmpty()) {
				final Element rootElement = ViewController.getRootElement();
				Element debugMessagesElement = rootElement.findElementById("jsxp:debug_messages");

				if(debugMessagesElement == null) {
					debugMessagesElement = rootElement.findElementByName("body", null);
				}

				if(debugMessagesElement != null) {
					debugMessagesElement.addElement(getElementDebugComponent());
					final DebugItem listItem = getElementDebugItem();
					listItem.remove();
					final ElementTemplate<DebugItem> template = listItem.createTemplate();
					for(final String debugMessage : Context.getContext().getDebugMessages()) {
						final Element we = template.createElement(null);
						we.setValue(debugMessage);
						getElementDebugMessagesList().addElement(we);
					}
					Context.getContext().getDebugMessages().clear();
				}
			}
		}
	}

	/**
	 * Instantiates a new debug messages controller.
	 */
	public DebugMessagesXhtmlController() {
		setNeedToSaveScopesToSession(false);
		getLifeCycle().addPhaseListener(LifeCyclePhase.RENDERING, new DebugMessagesPhaseListener());
	}
}
