/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.webroot.jsxpframework.components;

import org.jsxp.framework.Context;
import org.jsxp.framework.Element;
import org.jsxp.framework.ElementTemplate;
import org.jsxp.framework.PhaseListener;
import org.jsxp.framework.ViewController;
import org.jsxp.framework.ViewControllerLifeCycle.LifeCyclePhase;
import org.jsxp.framework.webroot.generated.jsxpframework.components.DeveloperWarningsXhtmlControllerGenerated;


/**
 * The Class DeveloperWarningsXhtmlController. {@link ViewController} for the basic jsxp warnings
 * component. This view controller is used per default to show the warning messages you can
 * add to the context on the result page from the requested view.
 * 
 * @see Context#addDeveloperWarningMessage(String)
 */
public class DeveloperWarningsXhtmlController extends DeveloperWarningsXhtmlControllerGenerated {

	private class DeveloperWarningsPhaseListener implements PhaseListener {

		/* (non-Javadoc)
		 * @see org.jsxp.framework.framework.PhaseListener#afterPhase(org.jsxp.framework.framework.ViewControllerLifeCycle.LifeCyclePhase)
		 */
		@Override
		public void afterPhase(final LifeCyclePhase phase) {
		}

		/* (non-Javadoc)
		 * @see org.jsxp.framework.framework.PhaseListener#beforePhase(org.jsxp.framework.framework.ViewControllerLifeCycle.LifeCyclePhase)
		 */
		@Override
		public void beforePhase(final LifeCyclePhase phase) {
			ViewController ViewController = getParent();
			while (ViewController.getViewTemplate() != null) {
				ViewController = ViewController.getViewTemplate();
			}
			if(!Context.getContext().getDeveloperWarnings().isEmpty()) {
				final Element rootElement = ViewController.getRootElement();
				final Element warningsElement = rootElement.findElementByName("body", null);

				if(warningsElement != null) {
					warningsElement.addElement(getElementWarningComponent());
					final WarningItem listItem = getElementWarningItem();
					listItem.remove();
					final ElementTemplate<WarningItem> template = listItem.createTemplate();
					for(final String warning : Context.getContext().getDeveloperWarnings()) {
						final Element we = template.createElement(null);
						we.setValue(warning);
						getElementWarningList().addElement(we);
					}
					Context.getContext().getDeveloperWarnings().clear();
				}
			}
		}
	}

	/**
	 * Instantiates a new developer warnings xhtml controller.
	 */
	public DeveloperWarningsXhtmlController() {
		setNeedToSaveScopesToSession(false);
		getLifeCycle().addPhaseListener(LifeCyclePhase.RENDERING, new DeveloperWarningsPhaseListener());
	}

}
