/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.webroot.jsxpframework.components;

import org.jsxp.framework.ViewController;
import org.jsxp.framework.webroot.generated.jsxpframework.components.ErrorXhtmlControllerGenerated;


/**
 * The Class ErrorXhtmlController. {@link ViewController} for the standard jsxp component to send
 * an error result page to the client. You can use it by creating a new instance from this error
 * controller by redirecting to this instance with the redirects methods of your
 * {@link ViewController}.
 */
public class ErrorXhtmlController extends  ErrorXhtmlControllerGenerated {

	private final String errorDescription;
	private final String errorMessage;
	private final int httpStatusCode;

	/**
	 * Instantiates a new error xhtml controller.
	 * 
	 * @param httpStatusCode the http status code
	 * @param errorMessage the error message
	 * @param errorDescription the error description
	 */
	public ErrorXhtmlController(final int httpStatusCode, final String errorMessage, final String errorDescription) {
		setNeedToSaveScopesToSession(false);
		this.httpStatusCode = httpStatusCode;
		this.errorMessage = errorMessage;
		this.errorDescription = errorDescription;
	}

	/* (non-Javadoc)
	 * @see org.jsxp.framework.framework.ViewController#getHttpStatusCode()
	 */
	@Override
	public int getStatusCode() {
		return httpStatusCode;
	}

	/* (non-Javadoc)
	 * @see org.jsxp.framework.framework.ViewController#init()
	 */
	@Override
	public void init() {
		setVariableErrorCode(""+httpStatusCode);
		setVariableErrorMessage(errorMessage);
		setVariableErrorDescription(errorDescription);
		setApplicationTemplateEnabled(false);
	}
}
