/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.webroot.jsxpframework.components;

import org.jsxp.framework.Context;
import org.jsxp.framework.Element;
import org.jsxp.framework.ElementTemplate;
import org.jsxp.framework.PhaseListener;
import org.jsxp.framework.ViewController;
import org.jsxp.framework.ViewControllerLifeCycle.LifeCyclePhase;
import org.jsxp.framework.webroot.generated.jsxpframework.components.FlashMessagesXhtmlControllerGenerated;


/**
 * The Class FlashMessagesXhtmlController. {@link ViewController} for the basic jsxp flash messages
 * component. This view controller is used per default to show flash messages (messages that are
 * managed in the flash scope and only exists till the next request) you can
 * add to the context on the result page from the requested view.
 * 
 * @see Context#getFlashMessages()
 */
public class FlashMessagesXhtmlController extends FlashMessagesXhtmlControllerGenerated {

	private class FlashMessagesPhaseListener implements PhaseListener {

		/* (non-Javadoc)
		 * @see org.jsxp.framework.framework.PhaseListener#afterPhase(org.jsxp.framework.framework.ViewControllerLifeCycle.LifeCyclePhase)
		 */
		@Override
		public void afterPhase(final LifeCyclePhase phase) {
		}

		/* (non-Javadoc)
		 * @see org.jsxp.framework.framework.PhaseListener#beforePhase(org.jsxp.framework.framework.ViewControllerLifeCycle.LifeCyclePhase)
		 */
		@Override
		public void beforePhase(final LifeCyclePhase phase) {
			if (!Context.getContext().getUpdateIds().isEmpty()) {
				Context.getContext().getUpdateIds().add(getElementFlashComponent().getId());
			}

			ViewController ViewController = getParent();
			while (ViewController.getViewTemplate() != null) {
				ViewController = ViewController.getViewTemplate();
			}
			final org.jsxp.framework.FlashMessages flashMessages = Context.getContext().getFlashMessages();
			if(!flashMessages.isEmpty()) {
				final Element rootElement = ViewController.getRootElement();
				Element messagesElement = rootElement.findElementById("jsxp:flash_messages");

				if(messagesElement == null) {
					messagesElement = rootElement.findElementByName("body", null);
				}

				if(messagesElement != null) {
					messagesElement.addElement(getElementFlashComponent());

					if(flashMessages.getErrorMessages() != null) {
						final ErrorItem listItem = getElementErrorItem();
						listItem.remove();
						final ElementTemplate<ErrorItem> template = listItem.createTemplate();
						for(final String message : flashMessages.getErrorMessages()) {
							final Element we = template.createElement(null);
							we.setValue(message);
							getElementFlashErrorsList().addElement(we);
						}
					} else {
						getElementFlashErrors().remove();
					}

					if(flashMessages.getWarningMessages() != null) {
						final WarningItem listItem = getElementWarningItem();
						listItem.remove();
						final ElementTemplate<WarningItem> template = listItem.createTemplate();
						for(final String message : flashMessages.getWarningMessages()) {
							final Element we = template.createElement(null);
							we.setValue(message);
							getElementFlashWarningsList().addElement(we);
						}
					} else {
						getElementFlashWarnings().remove();
					}

					if(flashMessages.getInfoMessages() != null) {
						final MessageItem listItem = getElementMessageItem();
						listItem.remove();
						final ElementTemplate<MessageItem> template = listItem.createTemplate();
						for(final String message : flashMessages.getInfoMessages()) {
							final Element we = template.createElement(null);
							we.setValue(message);
							getElementFlashMessagesList().addElement(we);
						}
					} else {
						getElementFlashMessages().remove();
					}
				}
			}
			flashMessages.clearLists();
		}
	}

	/**
	 * Instantiates a new flash messages xhtml controller.
	 */
	public FlashMessagesXhtmlController() {
		setNeedToSaveScopesToSession(false);
		getLifeCycle().addPhaseListener(LifeCyclePhase.RENDERING, new FlashMessagesPhaseListener());
	}
}
