/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.webroot.jsxpframework.components;

import java.util.Collection;
import java.util.LinkedList;
import java.util.List;

import org.jsxp.framework.Element;
import org.jsxp.framework.ElementTemplate;
import org.jsxp.framework.PhaseListener;
import org.jsxp.framework.ViewController;
import org.jsxp.framework.ViewControllerLifeCycle.LifeCyclePhase;
import org.jsxp.framework.webroot.generated.jsxpframework.components.MessagesXhtmlControllerGenerated;


/**
 * The Class MessagesXhtmlController. {@link ViewController} for the basic jsxp messages
 * component. This view controller can be used to show messages you can
 * set add the component on the result page from the requested view.
 */
public class MessagesXhtmlController extends MessagesXhtmlControllerGenerated {

	private class MessagesPhaseListener implements PhaseListener {

		/* (non-Javadoc)
		 * @see org.jsxp.framework.framework.PhaseListener#afterPhase(org.jsxp.framework.framework.ViewControllerLifeCycle.LifeCyclePhase)
		 */
		@Override
		public void afterPhase(final LifeCyclePhase phase) {
		}

		/* (non-Javadoc)
		 * @see org.jsxp.framework.framework.PhaseListener#beforePhase(org.jsxp.framework.framework.ViewControllerLifeCycle.LifeCyclePhase)
		 */
		@Override
		public void beforePhase(final LifeCyclePhase phase) {
			if(messages != null && !messages.isEmpty()) {
				final MessageItem listItem = getElementMessageItem();
				listItem.remove();
				final ElementTemplate<MessageItem> template = listItem.createTemplate();
				for(final String message : messages) {
					final Element we = template.createElement(null);
					we.setValue(message);
					getElementMessagesList().addElement(we);
				}
			}
		}
	}

	private Collection<String> messages = new LinkedList<String>();

	/**
	 * Instantiates a new messages xhtml controller.
	 */
	public MessagesXhtmlController() {
		setNeedToSaveScopesToSession(false);
		getLifeCycle().addPhaseListener(LifeCyclePhase.RENDERING, new MessagesPhaseListener());
	}

	/**
	 * Gets the messages.
	 * 
	 * @return the messages
	 */
	public Collection<String> getMessages() {
		return messages;
	}

	/**
	 * Sets the messages.
	 * 
	 * @param messages the new messages
	 */
	public void setMessages(final List<String> messages) {
		this.messages = messages;
	}

}
