/*   Copyright 2012 Oliver Szymanski & David Tanzer

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.jsxp.framework.webroot.jsxpframework.components;

import java.util.Map;

import org.jsxp.framework.Context;
import org.jsxp.framework.ViewController;
import org.jsxp.framework.webroot.generated.jsxpframework.components.RedirectViewXhtmlControllerGenerated;

/**
 * The Class RedirectViewXhtmlController. Standard {@link ViewController} to send a redirect to
 * the client. It is used automatically by the jsxp framework if you use the redirect methods of
 * a {@link ViewController}.
 */
public class RedirectViewXhtmlController extends RedirectViewXhtmlControllerGenerated {
	private final boolean clientRedirect;
	private final String redirectUri;

	/**
	 * Instantiates a new redirect view xhtml controller.
	 * 
	 * @param fromViewUri the from view uri
	 * @param redirectUri the redirect uri
	 * @param redirectParameters the redirect parameters
	 * @param clientRedirect true if the redirect is a client side redirect, otherwise it is a server side redirect
	 */
	public RedirectViewXhtmlController(final String fromViewUri, String redirectUri, final Map<String, Object[]> redirectParameters, final boolean clientRedirect) {
		final String[] parts = fromViewUri.split("/", -1);

		for(int i=0; i<parts.length-1; i++) {
			redirectUri = "../"+redirectUri;
		}

		if(redirectParameters != null) {
			redirectUri = redirectUri + "?";
			for(final String key : redirectParameters.keySet()) {
				for(final Object value : redirectParameters.get(key)) {
					if (value instanceof String) {
						redirectUri = redirectUri+key+"=";
						redirectUri = redirectUri+value;
						redirectUri = redirectUri+"&";
					}
				}
			}
			redirectUri = redirectUri.substring(0, redirectUri.length()-1);
		}

		this.redirectUri = redirectUri;
		this.clientRedirect = clientRedirect;
	}

	@Override
	public int getStatusCode()
	{
		if (!clientRedirect) {
			return 307;
		} else {
			return super.getStatusCode();
		}
	}

	/* (non-Javadoc)
	 * @see org.jsxp.framework.framework.ViewController#init()
	 */
	@Override
	public void init() throws Exception {
		setVariableRedirectUrl(redirectUri);
		setApplicationTemplateEnabled(false);

		if (!clientRedirect) {
			Context.getContext().getHttpServletResponse().setHeader("location", redirectUri);
		}
	}

}
